summary refs log tree commit diff
path: root/lib/python
diff options
context:
space:
mode:
Diffstat (limited to 'lib/python')
-rw-r--r--lib/python/qmk/cli/format/c.py2
-rw-r--r--lib/python/qmk/cli/new/keyboard.py4
2 files changed, 3 insertions, 3 deletions
diff --git a/lib/python/qmk/cli/format/c.py b/lib/python/qmk/cli/format/c.py
index b7263e19f3..0160e6036f 100644
--- a/lib/python/qmk/cli/format/c.py
+++ b/lib/python/qmk/cli/format/c.py
@@ -12,7 +12,7 @@ from qmk.c_parse import c_source_files
 
 c_file_suffixes = ('c', 'h', 'cpp')
 core_dirs = ('drivers', 'quantum', 'tests', 'tmk_core', 'platforms')
-ignored = ('tmk_core/protocol/usb_hid', 'quantum/template', 'platforms/chibios')
+ignored = ('tmk_core/protocol/usb_hid', 'platforms/chibios/boards')
 
 
 def find_clang_format():
diff --git a/lib/python/qmk/cli/new/keyboard.py b/lib/python/qmk/cli/new/keyboard.py
index 9e4232679d..369d2bd7da 100644
--- a/lib/python/qmk/cli/new/keyboard.py
+++ b/lib/python/qmk/cli/new/keyboard.py
@@ -115,9 +115,9 @@ def find_user_name():
 
 
 def copy_templates(keyboard_type, keyboard_path):
     """Copies the template files from quantum/template to the new keyboard directory.
     """
-    template_base_path = Path('quantum/template')
+    template_base_path = Path('data/templates')
     keyboard_basename = keyboard_path.name
 
     cli.log.info('Copying base template files...')
@@ -115,9 +115,9 @@ def find_user_name():
 
 def copy_templates(keyboard_type, keyboard_path):
-    """Copies the template files from quantum/template to the new keyboard directory.
+    """Copies the template files from data/templates to the new keyboard directory.
     """